"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.getSiteUrl = exports.getServer = exports.getAadTenant = exports.getAadUrl = exports.isPushChannelHostname = exports.isOdspHostname = void 0;
const odspTenants = new Map([
    ["spo", "microsoft-my.sharepoint.com"],
    ["spo-df", "microsoft-my.sharepoint-df.com"],
]);
/**
 * @internal
 */
function isOdspHostname(server) {
    return server.endsWith("sharepoint.com") || server.endsWith("sharepoint-df.com");
}
exports.isOdspHostname = isOdspHostname;
/**
 * @internal
 */
function isPushChannelHostname(server) {
    return server.includes(".push") && server.endsWith(".svc.ms");
}
exports.isPushChannelHostname = isPushChannelHostname;
/**
 * @internal
 */
function getAadUrl(server) {
    // special case for local / pushchannel testing
    if (server === "localhost" || server.startsWith("localhost:")) {
        // localhost will not be https
        return `http://${server}`;
    }
    if (isPushChannelHostname(server)) {
        // if the SPO url is pushchannel, use the pushchannel AAD mock
        return getSiteUrl(server);
    }
    return `https://login.microsoftonline.com`;
}
exports.getAadUrl = getAadUrl;
/**
 * @internal
 */
function getAadTenant(server) {
    let hostname = server;
    if (hostname.startsWith("http://")) {
        hostname = hostname.substring(7);
    }
    else if (hostname.startsWith("https://")) {
        hostname = hostname.substring(8);
    }
    let tenantName = hostname.substr(0, hostname.indexOf(".")).toLowerCase();
    let restOfTenantHostname = hostname.substr(tenantName.length).toLowerCase();
    if (tenantName.endsWith("-my")) {
        tenantName = tenantName.substr(0, tenantName.length - 3);
    }
    else if (tenantName.endsWith("-admin")) {
        tenantName = tenantName.substr(0, tenantName.length - 6);
    }
    if (restOfTenantHostname.startsWith(".sharepoint.")) {
        restOfTenantHostname = `.onmicrosoft.${restOfTenantHostname.substr(12)}`;
    }
    if (restOfTenantHostname.startsWith(".sharepoint-df.")) {
        restOfTenantHostname = `.onmicrosoft.${restOfTenantHostname.substr(15)}`;
    }
    return `${tenantName}${restOfTenantHostname}`;
}
exports.getAadTenant = getAadTenant;
/**
 * @internal
 */
function getServer(tenantId) {
    const server = odspTenants.get(tenantId);
    if (!server) {
        throw Error(`Invalid SPO tenantId ${tenantId}.`);
    }
    return server;
}
exports.getServer = getServer;
/**
 * @internal
 */
function getSiteUrl(server) {
    if (server.startsWith("http://") || server.startsWith("https://")) {
        // server is already a site url
        return server;
    }
    // server is likely {tenantId}.sharepoint.com. add https to make it the site url
    return `https://${server}`;
}
exports.getSiteUrl = getSiteUrl;
//# sourceMappingURL=odspDocLibUtils.js.map